import React from "react"
import PropTypes from "prop-types"
import { Map } from "immutable"

import SubtitlesButton from "../buttons/subtitles"
import TorrentsButton from "./torrents"
import ActionsButton from "./actions"

import ButtonToolbar from "react-bootstrap/ButtonToolbar"

const MovieButtons = (props)  => (
  <ButtonToolbar>
    <ActionsButton
      fetching={props.movie.get("fetchingDetails")}
      movieId={props.movie.get("imdb_id")}
      getDetails={props.getMovieDetails}
      deleteMovie={props.deleteMovie}
      hasMovie={(props.movie.get("polochon_url") !== "")}
      wishlisted={props.movie.get("wishlisted")}
      addToWishlist={props.addToWishlist}
      deleteFromWishlist={props.deleteFromWishlist}
      lastFetchUrl={props.lastFetchUrl}
    />

    <TorrentsButton
      movieTitle={props.movie.get("title")}
      torrents={props.movie.get("torrents")}
      addTorrent={props.addTorrent}
    />

    {props.movie.get("polochon_url") !== "" &&
        <SubtitlesButton
          fetching={props.movie.get("fetchingSubtitles")}
          subtitles={props.movie.get("subtitles")}
          refreshSubtitles={props.refreshSubtitles}
          resourceID={props.movie.get("imdb_id")}
          type="movie"
        />
    }
  </ButtonToolbar>
);
MovieButtons.propTypes = {
  movie: PropTypes.instanceOf(Map),
  refreshSubtitles: PropTypes.func.isRequired,
  addTorrent: PropTypes.func.isRequired,
  getDetails: PropTypes.func,
  deleteMovie: PropTypes.func.isRequired,
  addToWishlist: PropTypes.func.isRequired,
  deleteFromWishlist: PropTypes.func.isRequired,
  getMovieDetails: PropTypes.func.isRequired,
  lastFetchUrl: PropTypes.string,
}

export default MovieButtons;
